Code coverage report for index.js

# All files index.js

0% Statements 0/2
100% Branches 0/0
100% Functions 0/0
0% Lines 0/2

Press n or j to go to the next uncovered block, b, p or k for the previous block.

    1
    2
    3
    4
    5
    6
    7
    8
    9
    10

     import React from 'react';
    import ReactDOM from 'react-dom/client';
    import './index.css';
    import { PinCode } from './PinCode';

    const root = ReactDOM.createRoot(document.getElementById('pin_code'));
    root.render(
      <PinCode />
    );